import binary_c_python_api

from binarycpython.utils.functions import (
        get_defaults,
        create_arg_string,
        get_arg_keys,
    )

from binarycpython.utils.custom_logging_functions import (
    create_and_load_logging_function
)

def run_system(**kwargs):
    """
    Wrapper to run a system with settings 
    
    This function determines which underlying python-c api function will be called based upon the arguments that are passed via kwargs.

    - if custom_logging_code or custom_logging_dict is included in the kwargs then it will     
    - if 

    """

    # Load available arg keywords
    available_binary_c_arg_keywords = get_arg_keys()

    # Set default values
    func_memaddr = -1
    write_logfile = 0

    # Create dict to pass as argstring
    binary_c_args = {}

    # Check which binary_c arguments have been passed and put them into a dict
    for key in kwargs.keys():
        if key in available_binary_c_arg_keywords:
            binary_c_args[key] = kwargs[key]

    # Check if custom logging is required
    if "custom_logging_code" in kwargs:
        func_memaddr, shared_lib_filename = create_and_load_logging_function(kwargs["custom_logging_code"])

    # Check if writing logfile is required:
    if "log_filename" in kwargs:
        write_logfile = 1


    # Construct arguments string and final execution string
    arg_string = create_arg_string(binary_c_args)
    arg_string = "binary_c {}".format(arg_string)

    output = binary_c_python_api.run_system(arg_string, custom_logging_func_memaddr=func_memaddr, write_logfile=write_logfile)

    return output